@@ -15,7 +15,7 @@ with NML; if not, write to the Free Software Foundation, Inc.,
 
 import itertools
 
-from nml import generic, nmlop
+from nml import generic, nmlop, global_constants
 from nml.expression import (
     AcceptCargo,
     Array,
@@ -305,17 +305,22 @@ class VariableListProp(BaseAction0Property):
     Property value that is a variable-length list of variable sized values, the list length is written before the data.
     """
 
-    def __init__(self, prop_num, data, size):
+    def __init__(self, prop_num, data, size, extended):
         # data is a list, each element belongs to an item ID
         # Each element in the list is a list of cargo types
         self.prop_num = prop_num
         self.data = data
         self.size = size
+        self.extended = extended
 
     def write(self, file):
         file.print_bytex(self.prop_num)
         for elem in self.data:
-            file.print_byte(len(elem))
+            if self.extended:
+                file.print_bytex(0xFF)
+                file.print_word(len(elem))
+            else:
+                file.print_byte(len(elem))
             for i, val in enumerate(elem):
                 if i % 8 == 0:
                     file.newline()
@@ -325,13 +330,13 @@ class VariableListProp(BaseAction0Property):
     def get_size(self):
         total_len = 1  # Prop number
         for elem in self.data:
-            # For each item ID to set, make space for all values + 1 for the length
-            total_len += len(elem) * self.size + 1
+            # For each item ID to set, make space for all values + 3 or 1 for the length
+            total_len += len(elem) * self.size + (3 if self.extended else 1)
         return total_len
 
 
-def VariableByteListProp(prop_num, data):
-    return VariableListProp(prop_num, data, 1)
+def VariableByteListProp(prop_num, data, extended=False):
+    return VariableListProp(prop_num, data, 1, extended)
 
 
 def ctt_list(prop_num, *values):
@@ -348,8 +353,8 @@ def ctt_list(prop_num, *values):
     ]
 
 
-def VariableWordListProp(num_prop, data):
-    return VariableListProp(num_prop, data, 2)
+def VariableWordListProp(num_prop, data, extended=False):
+    return VariableListProp(num_prop, data, 2, extended)
 
 
 def accepted_cargos(prop_num, *values):
@@ -384,6 +389,29 @@ def zero_refit_mask(prop_num):
     return {"size": 4, "num": prop_num, "value_function": lambda value: ConstantNumeric(0)}
 
 
+def refittable_cargo_classes(prop_or_num, prop_and_num, refit_mask_num):
+    def prop_value(value, index):
+        if isinstance(value, ConstantNumeric):
+            return value if index == 0 else None
+        if isinstance(value, Array) and len(value.values) == 2 and isinstance(value.values[index], ConstantNumeric):
+            return value.values[index]
+        raise generic.ScriptError("refittable_cargo_classes must be a constant or an array of 2 constants")
+
+    def prop_test(value):
+        return value is not None
+
+    return [
+        {"size": 2, "num": prop_or_num, "value_function": lambda value: prop_value(value, 0)},
+        {
+            "size": 2,
+            "num": prop_and_num,
+            "value_function": lambda value: prop_value(value, 1),
+            "test_function": prop_test,
+        },
+        zero_refit_mask(refit_mask_num),
+    ]
+
+
 #
 # Feature 0x00 (Trains)
 #
@@ -435,7 +463,7 @@ properties[0x00] = {
     "bitmask_vehicle_info":           {"size": 1, "num": 0x25},
     "retire_early":                   {"size": 1, "num": 0x26},
     "misc_flags":                     {"size": 1, "num": 0x27},
-    "refittable_cargo_classes":       [{"size": 2, "num": 0x28}, zero_refit_mask(0x1D)],
+    "refittable_cargo_classes":       refittable_cargo_classes(0x28, 0x32, 0x1D),
     "non_refittable_cargo_classes":   [{"size": 2, "num": 0x29}, zero_refit_mask(0x1D)],
     "introduction_date":              {"size": 4, "num": 0x2A},
     "cargo_age_period":               {"size": 2, "num": 0x2B},
@@ -509,7 +537,7 @@ properties[0x01] = {
     "refit_cost":                   {"size": 1, "num": 0x1A},
     "retire_early":                 {"size": 1, "num": 0x1B},
     "misc_flags":                   {"size": 1, "num": 0x1C},
-    "refittable_cargo_classes":     [{"size": 2, "num": 0x1D}, zero_refit_mask(0x16)],
+    "refittable_cargo_classes":     refittable_cargo_classes(0x1D, 0x29, 0x16),
     "non_refittable_cargo_classes": [{"size": 2, "num": 0x1E}, zero_refit_mask(0x16)],
     "introduction_date":            {"size": 4, "num": 0x1F},
     # 20 (sort purchase list) is implemented elsewhere
@@ -599,7 +627,7 @@ properties[0x02] = {
     },
     "retire_early":                 {"size": 1, "num": 0x16},
     "misc_flags":                   {"size": 1, "num": 0x17},
-    "refittable_cargo_classes":     [{"size": 2, "num": 0x18}, zero_refit_mask(0x11)],
+    "refittable_cargo_classes":     refittable_cargo_classes(0x18, 0x25, 0x11),
     "non_refittable_cargo_classes": [{"size": 2, "num": 0x19}, zero_refit_mask(0x11)],
     "introduction_date":            {"size": 4, "num": 0x1A},
     # 1B (sort purchase list) is implemented elsewhere
@@ -663,7 +691,7 @@ properties[0x03] = {
     "refit_cost":                   {"size": 1, "num": 0x15},
     "retire_early":                 {"size": 1, "num": 0x16},
     "misc_flags":                   {"size": 1, "num": 0x17},
-    "refittable_cargo_classes":     [{"size": 2, "num": 0x18}, zero_refit_mask(0x13)],
+    "refittable_cargo_classes":     refittable_cargo_classes(0x18, 0x23, 0x13),
     "non_refittable_cargo_classes": [{"size": 2, "num": 0x19}, zero_refit_mask(0x13)],
     "introduction_date":            {"size": 4, "num": 0x1A},
     # 1B (sort purchase list) is implemented elsewhere
@@ -707,6 +735,89 @@ def cargo_bitmask(value):
     return BitMask(value.values, value.pos).reduce()
 
 
+class StationLayoutProp(BaseAction0Property):
+    def __init__(self, prop_num, data):
+        self.prop_num = prop_num
+        self.data = data
+
+    def write(self, file):
+        file.print_bytex(self.prop_num)
+        for (length, number), layout in self.data.items():
+            file.print_byte(length)
+            file.print_byte(number)
+            file.newline()
+            for platform in layout:
+                for type in platform:
+                    file.print_bytex(type)
+                file.newline()
+        file.print_byte(0)
+        file.print_byte(0)
+        file.newline()
+
+    def get_size(self):
+        total_len = 3  # Prop number + ending
+        for length, number in self.data:
+            total_len += length * number + 2
+        return total_len
+
+
+def station_layouts(value):
+    if isinstance(value, ConstantNumeric):
+        return [Action0Property(0x0F, value, 1 if value.value < 0xFF else 3)]
+    if not isinstance(value, Array) or len(value.values) == 0:
+        raise generic.ScriptError("station_layouts must be an array of layouts, or the ID of a station", value.pos)
+    layouts = {}
+    for layout in value.values:
+        if not isinstance(layout, Array) or len(layout.values) == 0:
+            raise generic.ScriptError("A station layout must be an array of platforms", layout.pos)
+        length = len(layout.values[0].values)
+        number = len(layout.values)
+        if (length, number) in layouts:
+            generic.print_warning(
+                generic.Warning.GENERIC, "Redefinition of layout {}x{}".format(length, number), layout.pos
+            )
+        layouts[(length, number)] = []
+        for platform in layout.values:
+            if not isinstance(platform, Array) or len(platform.values) == 0:
+                raise generic.ScriptError("A platform must be an array of tile types")
+            if len(platform.values) != length:
+                raise generic.ScriptError("All platforms in a station layout must have the same length", platform.pos)
+            for type in platform.values:
+                if type.reduce_constant().value % 2 != 0:
+                    generic.print_warning(
+                        generic.Warning.GENERIC,
+                        "Invalid tile {} in layout {}x{}".format(type, length, number),
+                        type.pos,
+                    )
+            layouts[(length, number)].append(
+                [nmlop.AND(type, 0xFE).reduce_constant().value for type in platform.values]
+            )
+    return [StationLayoutProp(0x0E, layouts)]
+
+
+def station_tile_flags(value):
+    if not isinstance(value, Array) or len(value.values) % 2 != 0:
+        raise generic.ScriptError("Flag list must be an array of even length", value.pos)
+    if len(value.values) > 8:
+        return [VariableByteListProp(0x1E, [[flags.reduce_constant().value for flags in value.values]], True)]
+    pylons = 0
+    wires = 0
+    blocked = 0
+    for i, val in enumerate(value.values):
+        flag = val.value
+        if flag & 1 << global_constants.constant_numbers["STAT_TILE_PYLON"]:
+            pylons = pylons | 1 << i
+        if flag & 1 << global_constants.constant_numbers["STAT_TILE_NOWIRE"]:
+            wires = wires | 1 << i
+        if flag & 1 << global_constants.constant_numbers["STAT_TILE_BLOCKED"]:
+            blocked = blocked | 1 << i
+    return [
+        Action0Property(0x11, ConstantNumeric(pylons), 1),
+        Action0Property(0x14, ConstantNumeric(wires), 1),
+        Action0Property(0x15, ConstantNumeric(blocked), 1),
+    ]
+
+
 # fmt: off
 properties[0x04] = {
     "class":                 {"size": 4, "num": 0x08, "first": None, "string_literal": 4},
@@ -715,14 +826,14 @@ properties[0x04] = {
     # 0B (callback flags) is not set by user
     "disabled_platforms":    {"size": 1, "num": 0x0C, "value_function": station_platforms_length},
     "disabled_length":       {"size": 1, "num": 0x0D, "value_function": station_platforms_length},
-    # 0E (station layout) callback 24 should be enough
-    # 0F (copy station layout)
+    "station_layouts":       {"custom_function": station_layouts},  # = prop 0E
+    # 0F (copy station layout) is handled by station_layouts
     "cargo_threshold":       {"size": 2, "num": 0x10},
-    "draw_pylon_tiles":      {"size": 1, "num": 0x11},
+    "draw_pylon_tiles":      {"size": 1, "num": 0x11, "replaced_by": "tile_flags"},
     "cargo_random_triggers": {"size": 4, "num": 0x12, "value_function": cargo_bitmask},
     "general_flags":         {"size": 1, "num": 0x13, "value_function": station_flags},
-    "hide_wire_tiles":       {"size": 1, "num": 0x14},
-    "non_traversable_tiles": {"size": 1, "num": 0x15},
+    "hide_wire_tiles":       {"size": 1, "num": 0x14, "replaced_by": "tile_flags"},
+    "non_traversable_tiles": {"size": 1, "num": 0x15, "replaced_by": "tile_flags"},
     "animation_info":        {"size": 2, "num": 0x16, "value_function": animation_info},
     "animation_speed":       {"size": 1, "num": 0x17},
     "animation_triggers":    {"size": 2, "num": 0x18},
@@ -731,6 +842,7 @@ properties[0x04] = {
     # 1B (minimum bridge height) JGR only
     "name":                  {"size": 2, "num": (256, -1, 0x1C), "string": (256, 0xC5, 0xDC), "required": True},
     "classname":             {"size": 2, "num": (256, -1, 0x1D), "string": (256, 0xC4, 0xDC)},
+    "tile_flags":            {"custom_function": station_tile_flags},  # = prop 1E
 }
 # fmt: on
 
