@@ -352,6 +352,7 @@ class Varaction2Parser:
         self.var_list = []
         self.var_list_size = 0
         self.proc_call_list = []
+        self.in_store_op = False
 
     def preprocess_binop(self, expr):
         """
@@ -571,10 +572,14 @@ class Varaction2Parser:
         if expr.op.act2_num is None:
             expr.supported_by_action2(True)
 
+        if expr.op == nmlop.STO_TMP:
+            self.in_store_op = True
+
         if (
             isinstance(expr.expr2, (expression.ConstantNumeric, expression.Variable))
             or isinstance(expr.expr2, (VarAction2LoadTempVar, VarAction2LoadCallParam))
             or (isinstance(expr.expr2, expression.Parameter) and isinstance(expr.expr2.num, expression.ConstantNumeric))
+            or (isinstance(expr.expr2, expression.StorageOp) and expr.expr2.name == "LOAD_TEMP")
             or expr.op == nmlop.VAL2
         ):
             expr2 = expr.expr2
@@ -601,6 +606,9 @@ class Varaction2Parser:
 
         self.parse(expr2)
 
+        if expr.op == nmlop.STO_TMP:
+            self.in_store_op = False
+
     def parse_constant(self, expr):
         var = VarAction2Var(0x1A, 0, expr.value)
         self.var_list.append(var)
@@ -614,7 +622,7 @@ class Varaction2Parser:
         self.var_list_size += var.get_size()
 
     def parse_string(self, expr):
-        str_id, actions = action4.get_string_action4s(0, 0xD0, expr)
+        str_id, actions = action4.get_string_action4s(0, 0xDC if self.in_store_op else 0xD0, expr)
         self.extra_actions.extend(actions)
         self.parse_constant(expression.ConstantNumeric(str_id))
 
@@ -1251,15 +1259,27 @@ def parse_varaction2(switch_block):
         # Computed result is not returned, but there are no ranges
         # Add one range, to avoid the nvar == 0 bear trap
         offset += 10
+        range_result, range_comment = parse_result(
+            expression.SpriteGroupRef(expression.Identifier("CB_FAILED", None), [], None),
+            action_list,
+            act6,
+            offset,
+            varaction2,
+            none_result,
+            switch_block.var_range,
+        )
         varaction2.ranges.append(
             VarAction2Range(
                 expression.ConstantNumeric(1),
                 expression.ConstantNumeric(0),
-                expression.ConstantNumeric(0),
+                range_result,
                 "Bogus range to avoid nvar == 0",
             )
         )
 
+    if len(varaction2.ranges) > 255:
+        raise generic.ScriptError("Too many ranges.", varaction2.pos)
+
     # Handle default result
     if switch_block.body.default is not None:
         # there is a default value
