@@ -40,6 +40,7 @@ general_vehicle_cbs = {
     'sound_effect'            : {'type': 'cb', 'num': 0x33, 'flag_bit': 7},
     'refit_cost'              : {'type': 'cb', 'num': 0x15E, 'purchase': 1},
     'name'                    : {'type': 'cb', 'num': 0x161, 'flag_bit': 8, 'purchase': 2},
+    'refit'                   : {'type': 'cb', 'num': 0x163, "purchase": 2},
 }
 
 # Function to convert vehicle length to the actual property value, which is (8 - length)
@@ -138,7 +139,7 @@ callbacks[0x03].update(general_vehicle_cbs)
 
 # Stations
 callbacks[0x04] = {
-    'availability'                  : {'type': 'cb', 'num':  0x13, 'flag_bit': 0},
+    'availability'                  : {'type': 'cb', 'num':  0x13, 'flag_bit': 0, 'purchase': 2},
     'select_sprite_layout'          : {'type': 'cb', 'num':  0x14, 'flag_bit': 1, 'purchase': 'purchase_select_sprite_layout'},
     'purchase_select_sprite_layout' : {'type': 'cb', 'num':  0x14, 'flag_bit': 1, 'purchase': 2},
     'select_tile_type'              : {'type': 'cb', 'num':  0x24, 'purchase': 2},
