@@ -13,7 +13,11 @@ You should have received a copy of the GNU General Public License along
 with NML; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA."""
 
-from PIL import Image
+try:
+    from PIL import Image
+except ImportError:
+    # Image is required only when using graphics
+    pass
 
 from nml import expression, generic
 from nml.actions import base_action
