@@ -14,10 +14,12 @@ with NML; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA."""
 
 import datetime
-from nml import generic, expression, nmlop
+
+from nml import expression, generic, nmlop
 from nml.actions import action0
 from nml.ast import base_statement
 
+
 class Snowline(base_statement.BaseStatement):
     """
     Snowline curve throughout the year.
@@ -28,20 +30,23 @@ class Snowline(base_statement.BaseStatement):
     @ivar date_heights: Height of the snow line at given days in the year.
     @type date_heights: C{list} of L{UnitAssignment}
     """
+
     def __init__(self, line_type, height_data, pos):
         base_statement.BaseStatement.__init__(self, "snowline-block", pos)
-        if line_type.value not in ('equal', 'linear'):
-            raise generic.ScriptError('Unknown type of snow line (only "equal" and "linear" are supported)', line_type.pos)
+        if line_type.value not in ("equal", "linear"):
+            raise generic.ScriptError(
+                'Unknown type of snow line (only "equal" and "linear" are supported)', line_type.pos
+            )
         self.type = line_type.value
         self.date_heights = height_data
 
     def debug_print(self, indentation):
-        generic.print_dbg(indentation, 'Snowline (type={})'.format(self.type))
+        generic.print_dbg(indentation, "Snowline (type={})".format(self.type))
         for dh in self.date_heights:
             dh.debug_print(indentation + 2)
 
     def __str__(self):
-        return 'snowline ({}) {{\n\t{}\n}}\n'.format(str(self.type), '\n\t'.join(str(x) for x in self.date_heights))
+        return "snowline ({}) {{\n\t{}\n}}\n".format(str(self.type), "\n\t".join(str(x) for x in self.date_heights))
 
     def get_action_list(self):
         return action0.get_snowlinetable_action(compute_table(self))
@@ -57,28 +62,27 @@ def compute_table(snowline):
     @return: Table of 12*32 entries with snowline heights.
     @rtype:  C{str}
     """
-    day_table = [None]*365 # Height at each day, starting at day 0
+    day_table = [None] * 365  # Height at each day, starting at day 0
     for dh in snowline.date_heights:
         doy = dh.name.reduce()
         if not isinstance(doy, expression.ConstantNumeric):
-            raise generic.ScriptError('Day of year is not a compile-time constant', doy.pos)
+            raise generic.ScriptError("Day of year is not a compile-time constant", doy.pos)
         if doy.value < 1 or doy.value > 365:
-            raise generic.ScriptError('Day of the year must be between 1 and 365', doy.pos)
+            raise generic.ScriptError("Day of the year must be between 1 and 365", doy.pos)
 
         height = dh.value.reduce()
         if isinstance(height, expression.ConstantNumeric) and height.value < 0:
-            raise generic.ScriptError('Height must be at least 0', height.pos)
+            raise generic.ScriptError("Height must be at least 0", height.pos)
         if dh.unit is None:
             if isinstance(height, expression.ConstantNumeric) and height.value > 255:
-                raise generic.ScriptError('Height must be at most 255', height.pos)
+                raise generic.ScriptError("Height must be at most 255", height.pos)
         else:
             unit = dh.unit
-            if unit.type != 'snowline':
+            if unit.type != "snowline":
                 raise generic.ScriptError('Expected a snowline percentage ("snow%")', height.pos)
 
             if isinstance(height, expression.ConstantNumeric) and height.value > 100:
-                raise generic.ScriptError('Height must be at most 100 snow%', height.pos)
-
+                raise generic.ScriptError("Height must be at most 100 snow%", height.pos)
 
             mul, div = unit.convert, 1
             if isinstance(mul, tuple):
@@ -94,13 +98,13 @@ def compute_table(snowline):
                 height = expression.ConstantNumeric(int(float(height.value) * mul / div + 0.5), height.pos)
             elif mul != div:
                 # Compute (value * mul + div/2) / div
-                height = expression.BinOp(nmlop.MUL, height, expression.ConstantNumeric(mul, height.pos), height.pos)
-                height = expression.BinOp(nmlop.ADD, height, expression.ConstantNumeric(int(div / 2), height.pos), height.pos)
-                height = expression.BinOp(nmlop.DIV, height, expression.ConstantNumeric(div, height.pos), height.pos)
+                height = nmlop.MUL(height, mul)
+                height = nmlop.ADD(height, int(div / 2))
+                height = nmlop.DIV(height, div)
 
         # For 'linear' snow-line, only accept integer constants.
-        if snowline.type != 'equal' and not isinstance(height, expression.ConstantNumeric):
-            raise generic.ScriptError('Height is not a compile-time constant', height.pos)
+        if snowline.type != "equal" and not isinstance(height, expression.ConstantNumeric):
+            raise generic.ScriptError("Height is not a compile-time constant", height.pos)
 
         day_table[doy.value - 1] = height
 
@@ -109,7 +113,7 @@ def compute_table(snowline):
     while start < 365 and day_table[start] is None:
         start = start + 1
     if start == 365:
-        raise generic.ScriptError('No heights given for the snowline table', snowline.pos)
+        raise generic.ScriptError("No heights given for the snowline table", snowline.pos)
 
     first_point = start
     while True:
@@ -125,16 +129,18 @@ def compute_table(snowline):
 
         # Fill the days between start and end (exclusive both border values)
         startvalue = day_table[start]
-        endvalue   = day_table[end]
+        endvalue = day_table[end]
         unwrapped_end = end
-        if end < start: unwrapped_end += 365
+        if end < start:
+            unwrapped_end += 365
 
-        if snowline.type == 'equal':
+        if snowline.type == "equal":
             for day in range(start + 1, unwrapped_end):
-                if day >= 365: day -= 365
+                if day >= 365:
+                    day -= 365
                 day_table[day] = startvalue
         else:
-            assert snowline.type == 'linear'
+            assert snowline.type == "linear"
 
             if start != end:
                 dhd = float(endvalue.value - startvalue.value) / float(unwrapped_end - start)
@@ -144,17 +150,17 @@ def compute_table(snowline):
 
             for day in range(start + 1, unwrapped_end):
                 uday = day
-                if uday >= 365: uday -= 365
+                if uday >= 365:
+                    uday -= 365
                 height = startvalue.value + int(round(dhd * (day - start)))
                 day_table[uday] = expression.ConstantNumeric(height)
 
-
-        if end == first_point: # All days done
+        if end == first_point:  # All days done
             break
 
         start = end
 
-    table = [None] * (12*32)
+    table = [None] * (12 * 32)
     for dy in range(365):
         today = datetime.date.fromordinal(dy + 1)
         if day_table[dy]:
@@ -166,11 +172,9 @@ def compute_table(snowline):
     for idx, d in enumerate(table):
         if d is None:
             table[idx] = table[idx - 1]
-    #Second loop is needed because we need make sure the first item is also set.
+    # Second loop is needed because we need make sure the first item is also set.
     for idx, d in enumerate(table):
         if d is None:
             table[idx] = table[idx - 1]
 
-
     return table
-
