@@ -123,7 +123,22 @@ class BinOp(Expression):
         if op in (nmlop.DIV, nmlop.DIVU, nmlop.MUL) and isinstance(expr2, ConstantNumeric) and expr2.value == 1:
             return expr1
 
-        if op in (nmlop.ADD, nmlop.SUB) and isinstance(expr2, ConstantNumeric) and expr2.value == 0:
+        if (
+            op
+            in (
+                nmlop.ADD,
+                nmlop.SUB,
+                nmlop.SHIFTU_LEFT,
+                nmlop.SHIFT_LEFT,
+                nmlop.SHIFTU_RIGHT,
+                nmlop.SHIFT_RIGHT,
+                nmlop.OR,
+                nmlop.XOR,
+                nmlop.ROT_RIGHT,
+            )
+            and isinstance(expr2, ConstantNumeric)
+            and expr2.value == 0
+        ):
             return expr1
 
         # - Variables (as used in action2var) can have some computations attached to
@@ -171,6 +186,24 @@ class BinOp(Expression):
                 expr1.mask = nmlop.SHIFT_LEFT(expr1.mask, expr2).reduce()
                 return expr1
 
+            if (
+                (
+                    op == nmlop.SHIFTU_RIGHT
+                    or (
+                        op == nmlop.SHIFT_RIGHT
+                        and isinstance(expr1.mask, ConstantNumeric)
+                        and expr1.mask.uvalue < 0x80000000
+                    )
+                )
+                and isinstance(expr2, ConstantNumeric)
+                and expr2.value >= 0
+                and expr1.shift.value >= 0
+                and (expr1.shift.value + expr2.value) < 32
+            ):
+                expr1.shift.value += expr2.value
+                expr1.mask = nmlop.SHIFTU_RIGHT(expr1.mask, expr2).reduce()
+                return expr1
+
         # - Try to merge multiple additions/subtractions with constant numbers
         if (
             op in (nmlop.ADD, nmlop.SUB)
