@@ -252,6 +252,11 @@ class RangeError(ScriptError):
         )
 
 
+class ProcCallSyntaxError(ScriptError):
+    def __init__(self, name, pos=None):
+        ScriptError.__init__(self, "Missing '()' after '{}'.".format(name), pos)
+
+
 class ImageError(ScriptError):
     def __init__(self, value, filename, pos=None):
         ScriptError.__init__(self, value, ImageFilePosition(filename, pos))
@@ -437,18 +442,23 @@ def print_warning(type, msg, pos=None):
     show_progress()
 
 
-def print_error(msg):
+def print_error(msg, pos=None):
     """
     Output an error message to the user.
     """
-    clear_progress()
+    if pos:
+        msg = str(pos) + ": " + msg
+    else:
+        clear_progress()
 
     msg = " nmlc ERROR: " + msg
 
     if sys.stderr.isatty():
         msg = "\033[91m" + msg + "\033[0m"
 
+    hide_progress()
     print(msg, file=sys.stderr)
+    show_progress()
 
 
 def print_dbg(indent, *args):
