@@ -59,6 +59,8 @@ constant_numbers = {
     "CC_POWDERIZED"   : 11,
     "CC_NON_POURABLE" : 12,
     "CC_NEO_BULK"     : 12,
+    "CC_POTABLE"      : 13,
+    "CC_NON_POTABLE"  : 14,
     "CC_SPECIAL"      : 15,
     "NO_CARGO_CLASS"           : 0,
     "ALL_NORMAL_CARGO_CLASSES" : 0x1FFF,
@@ -375,6 +377,11 @@ constant_numbers = {
     "STAT_FLAG_CUSTOM_FOUNDATIONS"    : 3,
     "STAT_FLAG_EXTENDED_FOUNDATIONS"  : 4,
 
+    # station tile flags
+    "STAT_TILE_PYLON"   : 0,
+    "STAT_TILE_NOWIRE"  : 1,
+    "STAT_TILE_BLOCKED" : 2,
+
     # station tiles
     "STAT_ALL_TILES"     : 0xFF,
 
@@ -1152,9 +1159,11 @@ constant_numbers = {
 
     "RST_TYPE_BUS"                              : 0,
     "RST_TYPE_TRUCK"                            : 1,
+    "RST_TYPE_WAYPOINT"                         : 2,
 
     "RST_DRAW_FLAG_BAY_ROAD"                    : 0,
     "RST_DRAW_FLAG_DRIVE_THROUGH_ROAD_OVERLAY"  : 1,
+    "RST_DRAW_FLAG_WAYPOINT_GROUND"             : 2,
 
     "RST_GENERAL_FLAG_RANDOM_ANIMATION"         : 0,
     "RST_GENERAL_FLAG_NO_CATENARY"              : 2,
@@ -1162,6 +1171,7 @@ constant_numbers = {
     "RST_GENERAL_FLAG_NO_AUTO_ROAD_CONNECTION"  : 4,
     "RST_GENERAL_FLAG_BUILD_MENU_ROAD_ONLY"     : 5,
     "RST_GENERAL_FLAG_BUILD_MENU_TRAM_ONLY"     : 6,
+    "RST_GENERAL_FLAG_DRAW_MODE_REGISTER"       : 8,
 
     "RST_VIEW_BAY_NE"                           : 0,
     "RST_VIEW_BAY_SE"                           : 1,
