@@ -825,6 +825,8 @@ class Language:
     @type strings: C{dict} of
     """
 
+    used_strings = []
+
     def __init__(self, default):
         self.default = default
         self.langid = None
@@ -985,6 +987,9 @@ class Language:
         assert string_id in self.strings
         assert lang_id == self.langid or self.langid == DEFAULT_LANGUAGE
 
+        if string_id not in Language.used_strings:
+            Language.used_strings.append(string_id)
+
         str_type = self.strings[string_id].get_type()
         parsed_string = ""
         if self.strings[string_id].gender is not None:
@@ -1229,7 +1234,7 @@ def parse_file(filename, default):
         with open(generic.find_file(filename), "r", encoding="utf-8") as fh:
             for idx, line in enumerate(fh):
                 pos = generic.LinePosition(filename, idx + 1)
-                line = line.rstrip("\n\r").lstrip("\uFEFF")
+                line = line.rstrip("\n\r").lstrip("\ufeff")
                 # The default language is processed twice here. Once as fallback langauge
                 # and once as normal language.
                 if default:
@@ -1291,3 +1296,10 @@ def read_lang_files(lang_dir, default_lang_file):
             continue
         parse_file(filename, False)
     langs.sort()
+
+
+def list_unused_strings():
+    for string in default_lang.strings:
+        if string in Language.used_strings:
+            continue
+        generic.print_warning(generic.Warning.GENERIC, 'String "{}" is unused'.format(string))
