@@ -53,6 +53,7 @@ try:
     from PIL import Image
 except ImportError:
     # Image is required only when using graphics
+    Image = None
     pass
 
 developmode = False  # Give 'nice' error message instead of a stack dump.
@@ -90,6 +91,7 @@ def parse_cli(argv):
         allow_extra_zoom=True,
         allow_32bpp=True,
         disable_palette_validation=False,
+        list_unused_strings=False,
     )
     opt_parser.add_option("-d", "--debug", action="store_true", dest="debug", help="write the AST to stdout")
     opt_parser.add_option("-s", "--stack", action="store_true", dest="stack", help="Dump stack when an error occurs")
@@ -231,6 +233,9 @@ def parse_cli(argv):
         dest="disable_palette_validation",
         help="Disable palette validation for sprites",
     )
+    opt_parser.add_option(
+        "--list-unused-strings", action="store_true", dest="list_unused_strings", help="List unused strings"
+    )
 
     opts, args = opt_parser.parse_args(argv)
 
@@ -359,6 +364,9 @@ def main(argv):
     )
 
     input.close()
+
+    if opts.list_unused_strings:
+        grfstrings.list_unused_strings()
     sys.exit(ret)
 
 
@@ -488,6 +496,11 @@ def nml(
             for sprite in action.sprite_list:
                 if sprite.is_empty:
                     continue
+
+                if not Image:
+                    generic.print_error("PIL (python-imaging) wasn't found, no support for using graphics")
+                    sys.exit(3)
+
                 sprite.validate_size()
 
                 file = sprite.file
@@ -518,10 +531,6 @@ def nml(
         generic.clear_progress()
         return 0
 
-    if not Image and len(sprite_files) > 0:
-        generic.print_error("PIL (python-imaging) wasn't found, no support for using graphics")
-        sys.exit(3)
-
     used_palette = forced_palette
 
     if not disable_palette_validation:
@@ -598,7 +607,6 @@ def nml(
     action0.print_stats()
     actionF.print_stats()
     action7.print_stats()
-    action1.print_stats()
     action2.print_stats()
     action6.print_stats()
     grf.print_stats()
